# Django Channels stubs
[![Test](https://github.com/huynguyengl99/channels-stubs/actions/workflows/test.yml/badge.svg?branch=main)](https://github.com/huynguyengl99/channels-stubs/actions/workflows/test.yml)
[![Checked with mypy](https://www.mypy-lang.org/static/mypy_badge.svg)](https://mypy-lang.org/)
[![PYPI](https://img.shields.io/pypi/v/channels-stubs)](https://pypi.org/project/channels-stubs/)


Stubs for [Django Channels](https://pypi.org/project/channels/).
Supports Python 3.10 and up. Supports Channels 4+.

## Installation

```bash
pip install channels-stubs
```

## Contributing

This project is open source and community driven. As such we encourage contributions big and small.
You can contribute by doing any of the following:

1. Contribute code (e.g. improve stubs, add plugin capabilities, write tests etc) - to do so please follow the [contribution guide](./CONTRIBUTING.md).
2. Assist in code reviews and discussions in issues.
3. Identify bugs and issues and report these

You can always also reach out in github to discuss your contributions!
